@@ -27,7 +27,7 @@ setLocalTranslate('cl_install3', sys.modules[__name__])
 
 from calculate.lib.utils.ip import (getInterfaces, getIp, getMask, getMac,
                                     cidrToMask, maskToCidr, getIpNet, isDhcpIp,
-                                    checkIp, checkMask,
+                                    checkIp, checkMask, isSlaveInterface,
                                     getOperState, getPlugged)
 from calculate.lib.utils.device import lspci
 from calculate.lib.utils.files import (listDirectory, readLinesFile)
@@ -187,6 +187,8 @@ class VariableOsInstallNetFqdn(NetHelper, Variable):
 
     def check(self, value):
         maxfqdn = 254
+        if " " in value:
+            raise VariableError(_("Wrong hostname"))
         if len(value) > maxfqdn:
             raise VariableError(
                 _("The hostname length should be less than %d") % maxfqdn)
@@ -278,6 +280,8 @@ class VariableOsInstallNetStatus(NetHelper, Variable):
         def statusValue(ipaddr, dhcp):
             if not getPlugged(iface):
                 return 'off'
+            if isSlaveInterface(iface):
+                return 'off'
             if dhcp == "on":
                 return "dhcp"
             elif ipaddr:
